@@ -80,7 +80,7 @@ class Controller:
         if name == "gns3vm":
             name = "Main server"
 
-        computes = await self._load_controller_settings()
+        computes = self._load_controller_settings()
         try:
             self._local_server = await self.add_compute(compute_id="local",
                                                         name=name,
@@ -118,7 +118,7 @@ class Controller:
 
     async def stop(self):
 
-        log.info("Controller is Stopping")
+        log.info("Controller is stopping")
         for project in self._projects.values():
             await project.close()
         for compute in self._computes.values():
@@ -132,6 +132,12 @@ class Controller:
         self._computes = {}
         self._projects = {}
 
+    async def reload(self):
+
+        log.info("Controller is reloading")
+        self._load_controller_settings()
+        await self.load_projects()
+
     def check_can_write_config(self):
         """
         Check if the controller configuration can be written on disk
@@ -182,7 +188,7 @@ class Controller:
         except OSError as e:
             log.error("Cannot write controller configuration file '{}': {}".format(self._config_file, e))
 
-    async def _load_controller_settings(self):
+    def _load_controller_settings(self):
         """
         Reload the controller configuration from disk
         """
@@ -199,7 +205,12 @@ class Controller:
 
         # load GNS3 VM settings
         if "gns3vm" in controller_settings:
-            self.gns3vm.settings = controller_settings["gns3vm"]
+            gns3_vm_settings = controller_settings["gns3vm"]
+            if "port" not in gns3_vm_settings:
+                # port setting was added in version 2.2.8
+                # the default port was 3080 before this
+                gns3_vm_settings["port"] = 3080
+            self.gns3vm.settings = gns3_vm_settings
 
         # load the IOU license settings
         if "iou_license" in controller_settings:
