@@ -129,6 +129,8 @@ class Project:
 
         self._iou_id_lock = asyncio.Lock()
 
+        log.debug('Project "{name}" [{id}] loaded'.format(name=self.name, id=self._id))
+
     def emit_notification(self, action, event):
         """
         Emit a notification to all clients using this project.
@@ -435,6 +437,9 @@ class Project:
         """
         :return: List of computes used by the project
         """
+
+        if self._status == "closed":
+            return self._get_closed_data("computes", "compute_id").values()
         return self._project_created_on_compute
 
     def remove_allocated_node_name(self, name):
@@ -994,7 +999,7 @@ class Project:
         while self._loading:
             await asyncio.sleep(0.5)
 
-    async def duplicate(self, name=None, location=None):
+    async def duplicate(self, name=None, location=None, reset_mac_addresses=True):
         """
         Duplicate a project
 
@@ -1004,6 +1009,7 @@ class Project:
 
         :param name: Name of the new project. A new one will be generated in case of conflicts
         :param location: Parent directory of the new project
+        :param reset_mac_addresses: Reset MAC addresses for the new project
         """
         # If the project was not open we open it temporary
         previous_status = self._status
@@ -1017,7 +1023,7 @@ class Project:
             with tempfile.TemporaryDirectory() as tmpdir:
                 # Do not compress the exported project when duplicating
                 with aiozipstream.ZipFile(compression=zipfile.ZIP_STORED) as zstream:
-                    await export_project(zstream, self, tmpdir, keep_compute_id=True, allow_all_nodes=True, reset_mac_addresses=True)
+                    await export_project(zstream, self, tmpdir, keep_compute_id=True, allow_all_nodes=True, reset_mac_addresses=reset_mac_addresses)
 
                     # export the project to a temporary location
                     project_path = os.path.join(tmpdir, "project.gns3p")
