@@ -15,22 +15,21 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+try:
+    import sentry_sdk
+    from sentry_sdk.integrations.logging import LoggingIntegration
+    SENTRY_SDK_AVAILABLE = True
+except ImportError:
+    # Sentry SDK is not installed with deb package in order to simplify packaging
+    SENTRY_SDK_AVAILABLE = False
+
 import os
 import sys
 import struct
-import aiohttp
 import platform
 import locale
 import distro
 
-try:
-    import raven
-    from raven.transport.http import HTTPTransport
-    RAVEN_AVAILABLE = True
-except ImportError:
-    # raven is not installed with deb package in order to simplify packaging
-    RAVEN_AVAILABLE = False
-
 from .version import __version__, __version_info__
 from .config import Config
 from .utils.get_resource import get_resource
@@ -43,7 +42,8 @@ log = logging.getLogger(__name__)
 if __version_info__[3] != 0:
     import faulthandler
 
-    # Display a traceback in case of segfault crash. Usefull when frozen
+    # Display a traceback in case of segfault crash.
+    # Useful when this application is frozen.
     # Not enabled by default for security reason
     log.info("Enable catching segfault")
     try:
@@ -58,49 +58,50 @@ class CrashReport:
     Report crash to a third party service
     """
 
-    DSN = "https://3b34198e8fa84f519ed6d6d5354c5cc5:1b0bec61fd654380b597ba4f11452f1f@o19455.ingest.sentry.io/38482"
-    if hasattr(sys, "frozen"):
-        cacert = get_resource("cacert.pem")
-        if cacert is not None and os.path.isfile(cacert):
-            DSN += "?ca_certs={}".format(cacert)
-        else:
-            log.warning("The SSL certificate bundle file '{}' could not be found".format(cacert))
+    DSN = "https://d4a76fe0441b47c28b19b66ce6d1c7c0:129a91b7ae0e4ec6acba1cccb61b97f3@o19455.ingest.sentry.io/38482"
     _instance = None
 
     def __init__(self):
-        self._client = None
 
-        # We don't want sentry making noise if an error is catched when you don't have internet
+        # We don't want sentry making noise if an error is caught when you don't have internet
         sentry_errors = logging.getLogger('sentry.errors')
         sentry_errors.disabled = True
 
         sentry_uncaught = logging.getLogger('sentry.errors.uncaught')
         sentry_uncaught.disabled = True
 
-    def capture_exception(self, request=None):
-        if not RAVEN_AVAILABLE:
-            return
-        if os.path.exists(".git"):
-            log.warning("A .git directory exist crash report is turn off for developers")
-            return
-        server_config = Config.instance().get_section_config("Server")
-        if server_config.getboolean("report_errors"):
-            if self._client is None:
-                self._client = raven.Client(CrashReport.DSN, release=__version__, raise_send_errors=True, transport=HTTPTransport)
-            if request is not None:
-                self._client.http_context({
-                    "method": request.method,
-                    "url": request.path,
-                    "data": request.json,
-                })
+        if SENTRY_SDK_AVAILABLE:
+            cacert = None
+            if hasattr(sys, "frozen"):
+                cacert_resource = get_resource("cacert.pem")
+                if cacert_resource is not None and os.path.isfile(cacert_resource):
+                    cacert = cacert_resource
+                else:
+                    log.error("The SSL certificate bundle file '{}' could not be found".format(cacert_resource))
 
-            context = {
+            # Don't send log records as events.
+            sentry_logging = LoggingIntegration(level=logging.INFO, event_level=None)
+
+            sentry_sdk.init(dsn=CrashReport.DSN,
+                            release=__version__,
+                            ca_certs=cacert,
+                            default_integrations=False,
+                            integrations=[sentry_logging])
+
+            tags = {
                 "os:name": platform.system(),
                 "os:release": platform.release(),
                 "os:win_32": " ".join(platform.win32_ver()),
                 "os:mac": "{} {}".format(platform.mac_ver()[0], platform.mac_ver()[2]),
                 "os:linux": " ".join(distro.linux_distribution()),
-                "aiohttp:version": aiohttp.__version__,
+
+            }
+
+            with sentry_sdk.configure_scope() as scope:
+                for key, value in tags.items():
+                    scope.set_tag(key, value)
+
+            extra_context = {
                 "python:version": "{}.{}.{}".format(sys.version_info[0],
                                                     sys.version_info[1],
                                                     sys.version_info[2]),
@@ -113,8 +114,8 @@ class CrashReport:
                 # add locale information
                 try:
                     language, encoding = locale.getlocale()
-                    context["locale:language"] = language
-                    context["locale:encoding"] = encoding
+                    extra_context["locale:language"] = language
+                    extra_context["locale:encoding"] = encoding
                 except ValueError:
                     pass
 
@@ -124,17 +125,47 @@ class CrashReport:
                 if os.path.isfile(gns3vm_version):
                     try:
                         with open(gns3vm_version) as fd:
-                            context["gns3vm:version"] = fd.readline().strip()
+                            extra_context["gns3vm:version"] = fd.readline().strip()
                     except OSError:
                         pass
 
-            self._client.tags_context(context)
-            try:
-                report = self._client.captureException()
-            except Exception as e:
-                log.error("Can't send crash report to Sentry: {}".format(e))
+            with sentry_sdk.configure_scope() as scope:
+                for key, value in extra_context.items():
+                    scope.set_extra(key, value)
+
+    def capture_exception(self, request):
+
+        if not SENTRY_SDK_AVAILABLE:
+            return
+
+        if not hasattr(sys, "frozen") and os.path.exists(os.path.join(os.path.dirname(os.path.abspath(__file__)), "..", ".git")):
+            log.warning(".git directory detected, crash reporting is turned off for developers.")
+            return
+
+        server_config = Config.instance().get_section_config("Server")
+        if server_config.getboolean("report_errors"):
+
+            if not SENTRY_SDK_AVAILABLE:
+                log.warning("Cannot capture exception: Sentry SDK is not available")
                 return
-            log.info("Crash report sent with event ID: {}".format(self._client.get_ident(report)))
+
+            if os.path.exists(".git"):
+                log.warning(".git directory detected, crash reporting is turned off for developers.")
+                return
+
+            try:
+                if request:
+                    # add specific extra request information
+                    with sentry_sdk.push_scope() as scope:
+                        scope.set_extra("method", request.method)
+                        scope.set_extra("url", request.path)
+                        scope.set_extra("json", request.json)
+                        sentry_sdk.capture_exception()
+                else:
+                    sentry_sdk.capture_exception()
+                log.info("Crash report sent with event ID: {}".format(sentry_sdk.last_event_id()))
+            except Exception as e:
+                log.warning("Can't send crash report to Sentry: {}".format(e))
 
     @classmethod
     def instance(cls):
